@@ -1,5 +1,5 @@
 package SVG::Estimate::Path;
-$SVG::Estimate::Path::VERSION = '1.0100';
+$SVG::Estimate::Path::VERSION = '1.0101';
 use Moo;
 use Image::SVG::Path qw/extract_path_info/;
 use SVG::Estimate::Path::Moveto;
@@ -20,7 +20,7 @@ SVG::Estimate::Path - Handles estimating arbitrary vectors.
 
 =head1 VERSION
 
-version 1.0100
+version 1.0101
 
 =head1 SYNOPSIS
 
@@ -55,6 +55,7 @@ An SVG path string as described L<http://www.w3.org/TR/SVG/paths.html>.
 has d => ( is => 'ro', required => 1, );
 has commands => ( is => 'ro', );
 has internal_travel_length => ( is => 'ro', required => 1, );
+has summarize => ( is => 'ro', default => sub { 0 }, );
 
 sub BUILDARGS {
     my ($class, @args) = @_;
@@ -66,7 +67,7 @@ sub BUILDARGS {
 
     my $first_flag = 1;
     my $first;
-    my $cursor  = [0, 0];  ##Updated after every command
+    my $cursor  = clone $args->{start_point};
     $args->{length} = 0;
     foreach my $subpath (@path_info) {
         $subpath->{transformer} = $args->{transformer};
@@ -102,6 +103,9 @@ sub BUILDARGS {
         $args->{max_x} = $command->max_x if $command->max_x > $args->{max_x};
         $args->{min_y} = $command->min_y if $command->min_y < $args->{min_y};
         $args->{max_y} = $command->max_y if $command->max_y > $args->{max_y};
+        if (exists $args->{summarize} && $args->{summarize}) {
+            $command->summarize_myself;
+        }
         push @commands, $command;
     }
 
