@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::Command;
-$SVG::Estimate::Path::Command::VERSION = '1.0100';
+$SVG::Estimate::Path::Command::VERSION = '1.0101';
 use Moo;
 with 'SVG::Estimate::Role::Round';
 
@@ -10,7 +10,7 @@ SVG::Estimate::Path::Command - Base class for all path calculations.
 
 =head1 VERSION
 
-version 1.0100
+version 1.0101
 
 =head1 DESCRIPTION
 
@@ -133,5 +133,20 @@ has max_y => (
     required    => 1,
 );
 
+has summarize => (
+    is          => 'ro',
+    default     => sub { 0 },
+);
+
+sub summarize_myself {
+    my $self = shift;
+    print "\t".ref $self;
+    printf "\n\t\tstart point: [%s, %s]", $self->round($self->start_point->[0]), $self->round($self->start_point->[1]);
+    printf "\n\t\tend   point: [%s, %s]", $self->round($self->end_point->[0]), $self->round($self->end_point->[1]);
+    print "\n\t\ttotal  length: ". $self->round($self->travel_length + $self->shape_length);
+    print "\n\t\ttravel length: ". $self->round($self->travel_length);
+    print "\n\t\tshape length:  ". $self->round($self->shape_length);
+    print "\n";
+}
 
 1;
