@@ -1,5 +1,5 @@
 package SVG::Estimate::Shape;
-$SVG::Estimate::Shape::VERSION = '1.0100';
+$SVG::Estimate::Shape::VERSION = '1.0101';
 use Moo;
 
 =head1 NAME
@@ -8,7 +8,7 @@ SVG::Estimate::Shape - Base class for all other shape calculations.
 
 =head1 VERSION
 
-version 1.0100
+version 1.0101
 
 =head1 DESCRIPTION
 
@@ -161,7 +161,16 @@ has max_y => (
     required    => 1,
 );
 
-
-
+sub summarize_myself {
+    my $self = shift;
+    print ref $self;
+    printf "\n\tstart point: [%s, %s]", $self->round($self->start_point->[0]), $self->round($self->start_point->[1]);
+    printf "\n\tdraw start : [%s, %s]", $self->round($self->draw_start->[0]), $self->round($self->draw_start->[1]);
+    printf "\n\tdraw end   : [%s, %s]", $self->round($self->draw_end->[0]), $self->round($self->draw_end->[1]);
+    print "\n\ttotal  length: ". $self->round($self->length);
+    print "\n\ttravel length: ". $self->round($self->travel_length);
+    print "\n\tshape length:  ". $self->round($self->shape_length);
+    print "\n";
+}
 
 1;
